@@ -97,8 +97,8 @@ if ($rootdir === $fileTreeRoot && $showPopular) {
     echo "<li class='popular-header small-caps-label' style='list-style:none;padding:5px 0 5px 20px;'>"._('Popular')."</li>";
     
     foreach ($popularPaths as $path) {
-      $htmlPath = htmlspecialchars($path);
-      $displayPath = htmlspecialchars($path);  // Show full path instead of basename
+      $htmlPath = htmlspecialchars($path, ENT_QUOTES);
+      $displayPath = htmlspecialchars($path, ENT_QUOTES);  // Show full path instead of basename
       // Use data-path instead of rel to prevent jQueryFileTree from handling these links
       // Use 'directory' class so jQueryFileTree CSS handles the icon
       echo "<li class='directory popular-destination' style='list-style:none;'>$checkbox<a href='#' data-path='$htmlPath'>$displayPath</a></li>";
@@ -134,22 +134,22 @@ if (is_dir($rootdir)) {
 
 // Normal mode: show directory tree
 if ($_POST['show_parent'] == 'true' && is_top($rootdir)) {
-  echo "<li class='directory collapsed'>$checkbox<a href='#' rel=\"".htmlspecialchars(dirname($rootdir))."\">..</a></li>";
+  echo "<li class='directory collapsed'>$checkbox<a href='#' rel=\"".htmlspecialchars(dirname($rootdir), ENT_QUOTES)."\">..</a></li>";
 }
 
 // Display directories and files (arrays already populated above)
 foreach ($dirs as $name) {
   // Exclude '.Recycle.Bin' from all shares and UD folders from '/mnt'
   if ($name === '.Recycle.Bin' || ($rootdir === $mntdir && in_array($name, $UDexcluded))) continue;
-  $htmlRel  = htmlspecialchars(my_dir($name).$name);
-  $htmlName = htmlspecialchars(mb_strlen($name) <= 33 ? $name : mb_substr($name, 0, 30).'...');
+  $htmlRel  = htmlspecialchars(my_dir($name).$name, ENT_QUOTES);
+  $htmlName = htmlspecialchars(mb_strlen($name) <= 33 ? $name : mb_substr($name, 0, 30).'...', ENT_QUOTES);
   if (empty($match) || preg_match("/$match/", $rootdir.$name.'/')) {
     echo "<li class='directory collapsed'>$checkbox<a href='#' rel=\"$htmlRel/\">$htmlName</a></li>";
   }
 }
 foreach ($files as $name) {
-  $htmlRel  = htmlspecialchars(my_dir($name).$name);
-  $htmlName = htmlspecialchars($name);
+  $htmlRel  = htmlspecialchars(my_dir($name).$name, ENT_QUOTES);
+  $htmlName = htmlspecialchars($name, ENT_QUOTES);
   $ext      = mb_strtolower(pathinfo($name, PATHINFO_EXTENSION));
   foreach ($filters as $filter) if (empty($filter) || $ext === $filter) {
     if (empty($match) || preg_match("/$match/", $name)) {
